#include <QApplication>
#include <QMainWindow>
#include <QTextCodec>
#include <QDebug>
#include <QLabel>
#include <QFontDatabase>
#include <QVBoxLayout>
#include <QPushButton>
#include "touchevent.h"

int main( int argc, char *argv[] )
{
	QApplication app( argc, argv );

	/* ソースコード中の文字列が UTF-8 であることを指定 */
	QTextCodec *codec = QTextCodec::codecForName(("UTF-8"));
	QTextCodec::setCodecForTr(codec);
	QTextCodec::setCodecForLocale(codec);
	QTextCodec::setCodecForCStrings(codec);

	/* 非暗号化日本語フォントの KBMincho をデフォルトフォントに設定 */
	QFontDatabase fontdb;
	fontdb.addApplicationFont("/usr/local/Kobo/fonts/KBMincho.ttf");
	app.setFont(fontdb.font("KBMincho", "Regular", 30));

	/* タッチイベントハンドラを作成 */
	TouchEvent *touch = new TouchEvent("/dev/input/event1");

	/* メインウィンドウを作成 */
	QMainWindow *win = new QMainWindow();
	QWidget *widget = new QWidget(win);
	QVBoxLayout *vbox = new QVBoxLayout(widget);

	QLabel *label = new QLabel("Kobo デベロッパへようこそ!!", widget);
	label->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
	vbox->addWidget(label);

	QPushButton *button = new QPushButton("終了", widget);
	QObject::connect(button, SIGNAL(clicked()), &app, SLOT(quit()));

	QHBoxLayout *hbox = new QHBoxLayout(widget);
	hbox->addWidget(new QWidget(widget));
	hbox->addWidget(button);
	hbox->addWidget(new QWidget(widget));

	vbox->addLayout(hbox);
	vbox->addWidget(new QWidget(widget));
	vbox->setStretch(0, 10);
	vbox->setStretch(1, 0);
	vbox->setStretch(2, 3);

	win->setCentralWidget(widget);
	win->showFullScreen();

	int ret = app.exec();

	return ret;
}

